"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const api_module_1 = require("./api-module");
class User extends api_module_1.default {
    async getUserInfo() {
        return await this.getReq('/auth/user');
    }
    async updateUserInfo(params) {
        return await this.putReq(`/users/${this.userId}`, params);
    }
    async getFriends(options = {}) {
        return await this.getReq('/auth/user/friends', options);
    }
    async getFriendStatus(userId) {
        return await this.getReq(`/user/${userId}/friendStatus`);
    }
    async sendFriendRequest(userId) {
        return await this.postReq(`/user/${userId}/friendRequest`);
    }
    async unfriend(userId) {
        return await this.deleteReq(`/auth/user/friends/${userId}`);
    }
    async acceptFriend(notificationId) {
        return await this.putReq(`/auth/user/notifications/${notificationId}/accept`);
    }
    async getById(userId) {
        return await this.getReq(`/users/${userId}`);
    }
    async getByName(username) {
        return await this.getReq(`/users/${username}/name`);
    }
    get search() {
        return {
            all: async (options = {}) => {
                return await this.getReq(`/users`, options);
            },
            /**
             * @deprecated 403 Error
             */
            active: async (options = {}) => {
                return await this.getReq(`/users/active`, options);
            },
        };
    }
}
exports.default = User;
