"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const axios_1 = require("axios");
const user_1 = require("./modules/user");
const avatar_1 = require("./modules/avatar");
const favorite_1 = require("./modules/favorite");
const world_1 = require("./modules/world");
const moderation_1 = require("./modules/moderation");
const notification_1 = require("./modules/notification");
const cookie = require('cookie');
class VrcApi {
    constructor(type = 'release') {
        this.url = 'https://api.vrchat.cloud/api/1';
        if (type === 'dev') {
            this.url = 'https://dev-api.vrchat.cloud/api/1/';
        }
        else if (type === 'beta') {
            this.url = 'https://beta-api.vrchat.cloud/api/1/';
        }
        this.vrc = axios_1.default.create({
            baseURL: this.url,
            headers: {
                'Content-Type': 'application/json',
                'X-Requested-With': 'XMLHttpRequest',
            },
            responseType: 'json',
        });
        this.user = new user_1.default(this);
        this.avatar = new avatar_1.default(this);
        this.favorite = new favorite_1.default(this);
        this.world = new world_1.default(this);
        this.moderation = new moderation_1.default(this);
        this.notification = new notification_1.default(this);
    }
    async login(username, password) {
        const apiKey = (await axios_1.default.get(`${this.url}/config`)).data.apiKey;
        const userRes = await axios_1.default.get(`${this.url}/auth/user`, {
            params: { apiKey: apiKey },
            auth: { username: username, password: password },
        });
        const token = cookie.parse(userRes.headers['set-cookie'][1]).auth;
        this._userId = userRes.data.id;
        this.vrc = axios_1.default.create({
            baseURL: this.url,
            headers: {
                'Content-Type': 'application/json',
                'X-Requested-With': 'XMLHttpRequest',
                'Cookie': `auth=${token}; apiKey=${apiKey}`,
            },
            responseType: 'json',
        });
    }
    get api() {
        return this.vrc;
    }
    get userId() {
        return this._userId;
    }
}
exports.default = VrcApi;
